@@ -1,6 +1,6 @@
 /*
 	Cadabra: a field-theory motivated computer algebra system.
-	Copyright (C) 2001-2009  Kasper Peeters <kasper.peeters@aei.mpg.de>
+	Copyright (C) 2001-2011  Kasper Peeters <kasper.peeters@aei.mpg.de>
 
    This program is free software: you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -1231,7 +1231,7 @@ void XCadabra::on_help_about()
 	md.set_website("http://cadabra.phi-sci.com/");
 	md.set_website_label("cadabra website");
 	md.set_version(RELEASE);
-	md.set_copyright("\xC2\xA9 2006-2010 Kasper Peeters");
+	md.set_copyright("\xC2\xA9 2006-2011 Kasper Peeters");
 	md.set_comments("Graphical user interface for the cadabra symbolic computer algebra system.");
 	md.set_license("XCadabra and Cadabra are available under the Gnu General Public License version 2.\n\nIf you use Cadabra or even just play with it, I would like to hear about it. Please send me an email so that I can get an idea of who is interested in this program.\n\nIf you use Cadabra in your own work, please cite both\n\nKasper Peeters\n\"A field-theory motivated approach to computer algebra\"\ncs.sc/0608005\nComput. Phys. Commun 176 (2007) 550\n\nKasper Peeters\n\"Introducing Cadabra: a symbolic computer algebra system for field theory problems\"\nhep-th/0701238\n\nThank you!");
 #if (GTKMM_VER == 28 || GTKMM_VER == 212 || GTKMM_VER == 216)
@@ -1239,7 +1239,10 @@ void XCadabra::on_help_about()
 #endif
 
 	std::vector<std::string> authors;
-	authors.push_back("Kasper Peeters <kasper.peeters@aei.mpg.de>");
+	authors.push_back("Kasper Peeters <kasper.peeters@aei.mpg.de>\n");
+	authors.push_back("with contributions by:");
+	authors.push_back("\tJosé M. Martín-García");
+	authors.push_back("\tJames Allen");
 	md.set_authors(authors);
 
 	md.run();
