@@ -1,7 +1,7 @@
 /* 
 
 	Cadabra: a field-theory motivated computer algebra system.
-	Copyright (C) 2001-2009  Kasper Peeters <kasper.peeters@aei.mpg.de>
+	Copyright (C) 2001-2011  Kasper Peeters <kasper.peeters@aei.mpg.de>
 
    This program is free software: you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -60,12 +60,12 @@ pattern::pattern()
 	{
 	}
 
-pattern::pattern(const exptree::iterator_base& it)
-	: obj(it), headnode(it->name)
+pattern::pattern(const exptree& o)
+	: obj(o)
 	{
 	}
 
-bool pattern::match(const exptree::iterator& it) const
+bool pattern::match(const exptree::iterator& it, bool ignore_parent_rel) const
 	{
 	// Special case for range wildcards.
 	// FIXME: move this to storage.cc (see the FIXME there)
@@ -87,7 +87,7 @@ bool pattern::match(const exptree::iterator& it) const
 				seqarg.skip_children();
 				++seqarg;
 				}
-			ind=properties::get<Indices>(stt);
+			ind=properties::get<Indices>(stt, true);
 			}
 		else seqarg=hmarg;
 
@@ -105,7 +105,7 @@ bool pattern::match(const exptree::iterator& it) const
 		if(ind!=0) {
 			exptree::sibling_iterator indit=it.begin();
 			while(indit!=it.end()) {
-				const Indices *gi=properties::get<Indices>(indit);
+				const Indices *gi=properties::get<Indices>(indit, true);
 				if(gi!=ind) {
 					return false;
 					}
@@ -120,7 +120,8 @@ bool pattern::match(const exptree::iterator& it) const
 //	txtout << "comparing " << *it->name << " " << *obj.begin()->name << std::endl;
 //	exptree::print_recursive_treeform(txtout, it);
 //	exptree::print_recursive_treeform(txtout, obj.begin());
-	int res=subtree_compare(it, obj.begin(), 0, true, 0);
+	int res=subtree_compare(it, obj.begin(), ignore_parent_rel?0:-2, true, 0);
+//	txtout << res << std::endl;
 	if(abs(res)<=1) {
 //		 txtout << "match!" << std::endl;
 		 return true;
@@ -312,14 +313,14 @@ bool operator<(const pattern& one, const pattern& two)
 //	  return one.obj==two.obj; // FIXME: handle dummy indices
 //	  }
 
-void properties::insert_prop(exptree::iterator it, const property *pr)
+void properties::insert_prop(const exptree& et, const property *pr)
 	{
 //	assert(pats.find(pr)==pats.end()); // identical properties have to be assigned through insert_list_prop
 
-	pattern *pat=new pattern(it);
+	pattern *pat=new pattern(et);
 
 	std::pair<property_map_t::iterator, property_map_t::iterator> pit=
-		props.equal_range(it->name);
+		props.equal_range(pat->obj.begin()->name_only());
 
 	property_map_t::iterator first_nonpattern=pit.first;
 
@@ -329,7 +330,7 @@ void properties::insert_prop(exptree::iterator it, const property *pr)
 			if((*pit.first).second.first->obj.begin().begin()->is_range_wildcard()) 
 				++first_nonpattern;
 			
-		if((*pit.first).second.first->match(it)) { // match found
+		if((*pit.first).second.first->match(et.begin())) { // match found
 			if(typeid(*pr)==typeid(*(*pit.first).second.second)) {
 				const labelled_property *lp   =dynamic_cast<const labelled_property *>(pr);
 				const labelled_property *lpold=dynamic_cast<const labelled_property *>(pit.first->second.second);
@@ -349,10 +350,10 @@ void properties::insert_prop(exptree::iterator it, const property *pr)
 		}
 
 	pats.insert(pattern_map_t::value_type(pr, pat));
-	properties::props.insert(property_map_t::value_type(it->name, pat_prop_pair_t(pat,pr)));
+	properties::props.insert(property_map_t::value_type(pat->obj.begin()->name_only(), pat_prop_pair_t(pat,pr)));
 	}
 
-void properties::insert_list_prop(const std::vector<exptree::iterator>& its, const list_property *pr)
+void properties::insert_list_prop(const std::vector<exptree>& its, const list_property *pr)
 	{
 	assert(pats.find(pr)==pats.end()); // identical properties have to be assigned through insert_list_prop
 	assert(its.size()>0);
@@ -440,7 +441,7 @@ void properties::insert_list_prop(const std::vector<exptree::iterator>& its, con
 		// Now register the property.
 //		txtout << "registering " << *(pat->headnode) << std::endl;
 		pats.insert(pattern_map_t::value_type(pr, pat));
-		properties::props.insert(property_map_t::value_type(its[i]->name, pat_prop_pair_t(pat,pr)));
+		properties::props.insert(property_map_t::value_type(pat->obj.begin()->name_only(), pat_prop_pair_t(pat,pr)));
 		}
 	}
 
@@ -496,6 +497,23 @@ std::string Symbol::name() const
 	return "Symbol";
 	}
 
+const Symbol *Symbol::get(exptree::iterator it, bool ignore_parent_rel) 
+	{
+	if(*it->name=="\\sum") {
+		// Check whether all siblings have the Symbol property.
+		exptree::sibling_iterator sib=it.begin();
+		const Symbol *s=0;
+		while(sib!=it.end()) {
+			s = properties::get<Symbol>(sib, ignore_parent_rel);
+			if(!s)
+				break;
+			++sib;
+			}
+		return s;
+		}
+	else return properties::get<Symbol>(it, ignore_parent_rel);
+	}
+
 std::string Coordinate::name() const
 	{
 	return "Coordinate";
